@@ -599,5 +599,21 @@ defer <- function(expr, envir = parent.frame()) {
 
   # Use 'do.call' with 'on.exit' to attach the evaluation to
   # the exit handlrs of the selected frame
-  do.call("on.exit", list(substitute(call), add = TRUE), envir = envir)
+  do.call(base::on.exit, list(substitute(call), add = TRUE), envir = envir)
+}
+
+isUsingExternalTar <- function() {
+
+  TAR <- Sys.getenv("TAR")
+
+  if (!nzchar(TAR))
+    return(FALSE)
+
+  if (!nzchar(Sys.which(TAR)))
+    return(FALSE)
+
+  if (identical(TAR, "internal"))
+    return(FALSE)
+
+  TRUE
 }
